Crate wasm_p2p

Crate wasm_p2p 

Re-exports

pub use p2p::P2P;
pub use wasm_bindgen_futures;

Modules

ice_server
messages
p2p
p2p_connection
utils

Macros

console_log

Structs

JsError
Convenience type for use on exported fn() -> Result<T, JsError> functions, where you wish to throw a JavaScript Error object.
JsValue
Representation of an object owned by JS.
ScopedClosure
A closure with a lifetime parameter that represents a Rust closure passed to JavaScript.

Traits

JsCast
A trait for dynamic checked and unchecked casting between JS types.
UnwrapThrowExt
An extension trait for Option<T> and Result<T, E> for unwrapping the T value, or throwing a JS error if it is not available.
Upcast
A trait for type-safe generic upcasting.

Type Aliases

Closure
Alias for ScopedClosure<'static, T> for backwards compatibility.

Attribute Macros

__wasm_bindgen_class_marker
wasm_bindgen
A list of all the attributes can be found here: https://wasm-bindgen.github.io/wasm-bindgen/reference/attributes/index.html