Re-exports
pub use p2p::P2P;pub use wasm_bindgen_futures;
Modules
Macros
Structs
- JsError
- Convenience type for use on exported
fn() -> Result<T, JsError>functions, where you wish to throw a JavaScriptErrorobject. - JsValue
- Representation of an object owned by JS.
- Scoped
Closure - A closure with a lifetime parameter that represents a Rust closure passed to JavaScript.
Traits
- JsCast
- A trait for dynamic checked and unchecked casting between JS types.
- Unwrap
Throw Ext - An extension trait for
Option<T>andResult<T, E>for unwrapping theTvalue, or throwing a JS error if it is not available. - Upcast
- A trait for type-safe generic upcasting.
Type Aliases
- Closure
- Alias for
ScopedClosure<'static, T>for backwards compatibility.
Attribute Macros
- __
wasm_ bindgen_ class_ marker - wasm_
bindgen - A list of all the attributes can be found here: https://wasm-bindgen.github.io/wasm-bindgen/reference/attributes/index.html